Module daemon

Module daemon 

Vetto Multiplexer Daemon and Session Orchestrator.

Exposes:

  • Unix Domain Socket with mandatory SO_PEERCRED authentication
  • Loopback HTTP REST API with Bearer token authentication
  • Persistent and in-memory session registry

Modules

auth
Authentication and security validation for vetto daemon and REST endpoints.
http
Lightweight REST HTTP API server bound strictly to loopback (127.0.0.1).
registry
In-memory and persistent session registry for the multiplexer daemon.
socket
Unix Domain Socket multiplexer listener with mandatory SO_PEERCRED / getpeereid auth.

Enums

DaemonCommand

Constants

DEFAULT_HTTP_PORT

Functions

query_daemon_status
run_cli
start_daemon
stop_daemon